pub struct ReifiedVar(pub usize);Expand description
Reified logic variable.
Reified variables represent logic variables that remain fresh after goals have run.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for ReifiedVar
impl Clone for ReifiedVar
Sourcefn clone(&self) -> ReifiedVar
fn clone(&self) -> ReifiedVar
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReifiedVar
impl Debug for ReifiedVar
Sourceimpl PartialEq for ReifiedVar
impl PartialEq for ReifiedVar
Sourceimpl Structure for ReifiedVar
impl Structure for ReifiedVar
Sourcefn occurs<'s>(&self, _x: &Var, _s: &Substitution<'s>) -> bool
fn occurs<'s>(&self, _x: &Var, _s: &Substitution<'s>) -> bool
Returns
true if self contains a variable that is equivalent
to x when considering substitution s.Sourcefn unify<'s>(
&self,
_v: &Value,
_s: Substitution<'s>,
) -> Option<Substitution<'s>>
fn unify<'s>( &self, _v: &Value, _s: Substitution<'s>, ) -> Option<Substitution<'s>>
Attempt to unify
self with Value v under substitution s.Sourcefn walk_star(self: Arc<Self>, _: &Substitution<'_>) -> Value
fn walk_star(self: Arc<Self>, _: &Substitution<'_>) -> Value
Recursively replace any variables contained in
self with
their substituted values.Sourcefn reify_s<'s>(&self, s: Substitution<'s>) -> Substitution<'s>
fn reify_s<'s>(&self, s: Substitution<'s>) -> Substitution<'s>
Substitute all variables that remain fresh in
self with reified variables.impl Copy for ReifiedVar
impl Eq for ReifiedVar
impl StructuralPartialEq for ReifiedVar