Var

Struct Var 

pub struct Var { /* private fields */ }
Named logic variable.

The variable name is purely descriptive to help understanding. Any newly created variables is different from all previously created variables, even if they have the same name. However, variables can be copied, which preserves identity.

Implementations

Source

impl Var

pub fn new(name: &'static str) -> Self

Create a new unique logic variable.

pub fn name(&self) -> &str

Return the variable’s name.