pub struct Var { /* private fields */ }Expand description
Named logic variable.
The variable name is purely descriptive to help understanding. Any newly created variables is different from all previously created variables, even if they have the same name. However, variables can be copied, which preserves identity.
Implementations